#ifndef PYTHONIC_PP_H
#define PYTHONIC_PP_H

/* core */
#include "core/utils.h"
#include "core/functional.h"
#include "core/none.h"
#include "core/string.h"
#include "core/list.h"
#include "core/exceptions.h"
#include "core/iterator.h"
#include "core/set.h"
#include "core/dict.h"
#include "core/tuple.h"
#include "core/io.h"
#include "core/intrinsics.h"

/* additional modules */
#include "modules/dispatch.h"
#include "modules/list.h"
#include "modules/set.h"
#include "modules/dict.h"
#include "modules/complex.h"
#include "modules/math.h"
#include "modules/cmath.h"
#include "modules/random.h"
#include "modules/iterator.h"
#include "modules/string.h"
#include "modules/time.h"
#include "modules/omp.h"

/* extensions */
#include "core/parallel.h"

#endif
